@@ -21,6 +21,7 @@
 
 #include "commands/file-commands.hpp"
 #include "commands/file-tasks/task-open.hpp"
+#include "commands/file-tasks/task-open-multiple.hpp"
 
 namespace Gobby
 {
@@ -30,11 +31,14 @@ class TaskOpenFile: public FileCommands::Task
 public:
 	TaskOpenFile(FileCommands& file_commands);
 
+	virtual void run();
+
 private:
 	void on_file_response(int response_id);
 
 	FileChooser::Dialog m_file_dialog;
 	std::auto_ptr<TaskOpen> m_open_task;
+	std::auto_ptr<TaskOpenMultiple> m_open_taskm;
 };
 
 } // namespace Gobby
