@@ -21,6 +21,8 @@
 
 #include "commands/file-commands.hpp"
 
+#include <giomm/file.h>
+
 namespace Gobby
 {
 
@@ -31,6 +33,8 @@ public:
 	         const Glib::RefPtr<Gio::File>& file);
 	virtual ~TaskOpen();
 
+	virtual void run();
+
 private:
 	void on_query_info(const Glib::RefPtr<Gio::AsyncResult>& result);
 	void on_location_response(int response_id);
