@@ -1,5 +1,5 @@
 /* Gobby - GTK-based collaborative text editor
- * Copyright (C) 2008, 2009 Armin Burgmeier <armin@arbur.net>
+ * Copyright (C) 2008 Armin Burgmeier <armin@arbur.net>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public
@@ -40,6 +40,9 @@ namespace {
 		"      <menuitem action=\"FileSaveAs\" />"
 		"      <menuitem action=\"FileSaveAll\" />"
 		"      <separator />"
+		"      <menuitem action=\"FileExportHtml\" />"
+		"      <menuitem action=\"FileConnect\" />"
+		"      <separator />"
 		"      <menuitem action=\"FileClose\" />"
 		"      <menuitem action=\"FileQuit\" />"
 		"    </menu>"
@@ -60,11 +63,15 @@ namespace {
 		"      <menuitem action=\"EditPreferences\" />"
 		"    </menu>"
 		"    <menu action=\"MenuView\">"
+		"      <menuitem action=\"ViewHideUserColors\" />"
+		"      <separator />"
 		"      <menuitem action=\"ViewToolbar\" />"
 		"      <menuitem action=\"ViewStatusbar\" />"
 		"      <separator />"
 		"      <menuitem action=\"ViewBrowser\" />"
-		"      <menuitem action=\"ViewUserlist\" />"
+		"      <menuitem action=\"ViewChat\" />"
+		"      <menuitem action=\"ViewDocumentUserList\" />"
+		"      <menuitem action=\"ViewChatUserList\" />"
 		"      <separator />"
 		"      <menu action=\"ViewHighlightMode\">"
 		"        <menuitem"
@@ -72,6 +79,8 @@ namespace {
 		"      </menu>"
 		"    </menu>"
 		"    <menu action=\"MenuHelp\">"
+		"      <menuitem action=\"HelpContents\" />"
+		"      <separator />"
 		"      <menuitem action=\"HelpAbout\" />"
 		"    </menu>"
 		"  </menubar>"
@@ -203,6 +212,8 @@ Gobby::Header::Header(Preferences& preferences,
                       GtkSourceLanguageManager* lang_mgr):
 	m_preferences(preferences),
 
+	m_ui_manager(Gtk::UIManager::create()),
+
 	group_file(Gtk::ActionGroup::create("MenuFile") ),
 	group_edit(Gtk::ActionGroup::create("MenuEdit") ),
 	group_view(Gtk::ActionGroup::create("MenuView") ),
@@ -223,6 +234,11 @@ Gobby::Header::Header(Preferences& preferences,
 		Gtk::Action::create(
 			"FileSaveAll", Gobby::IconManager::STOCK_SAVE_ALL,
 			_("Save All"), _("Save all open files locally"))),
+	action_file_export_html(
+		Gtk::Action::create("FileExportHtml", _("Export As _HTML..."))),
+	action_file_connect(
+		Gtk::Action::create("FileConnect", Gtk::Stock::CONNECT,
+		                    _("Connect _to Server..."))),
 	action_file_close(
 		Gtk::Action::create("FileClose", Gtk::Stock::CLOSE)),
 	action_file_quit(Gtk::Action::create("FileQuit", Gtk::Stock::QUIT)),
@@ -258,10 +274,14 @@ Gobby::Header::Header(Preferences& preferences,
 		                    _("Pr_eferences..."))),
 
 	action_view(Gtk::Action::create("MenuView", _("_View"))),
+	action_view_hide_user_colors(
+		Gtk::Action::create(
+			"ViewHideUserColors", _("Reset User Colors"),
+			_("Hide user colors in current document"))),
 	action_view_toolbar(
 		Gtk::ToggleAction::create(
 			"ViewToolbar", _("View Toolbar"),
-		        _("Whether to show the toolbar"), 
+		        _("Whether to show the toolbar"),
 			preferences.appearance.show_toolbar)),
 	action_view_statusbar(
 		Gtk::ToggleAction::create(
@@ -273,11 +293,21 @@ Gobby::Header::Header(Preferences& preferences,
 			"ViewBrowser", _("View Document Browser"),
 			_("Whether to show the document browser"),
 			preferences.appearance.show_browser)),
-	action_view_userlist(
+	action_view_chat(
 		Gtk::ToggleAction::create(
-			"ViewUserlist", _("View User List"),
-			_("Whether to show the user list"),
-			preferences.appearance.show_userlist)),
+			"ViewChat", _("View Chat"),
+			_("Whether to show the chat pane"),
+			preferences.appearance.show_chat)),
+	action_view_document_userlist(
+		Gtk::ToggleAction::create(
+			"ViewDocumentUserList", _("View Document User List"),
+			_("Whether to show the user list for documents"),
+			preferences.appearance.show_document_userlist)),
+	action_view_chat_userlist(
+		Gtk::ToggleAction::create(
+			"ViewChatUserList", _("View Chat User List"),
+			_("Whether to show the user list for the chat"),
+			preferences.appearance.show_chat_userlist)),
 	action_view_highlight_mode(
 		Gtk::Action::create("ViewHighlightMode",
 		                    _("_Highlight Mode"))),
@@ -287,12 +317,14 @@ Gobby::Header::Header(Preferences& preferences,
 		load_highlight_languages(lang_mgr, m_highlight_group)),
 
 	action_help(Gtk::Action::create("MenuHelp", _("_Help")) ),
+	action_help_contents(
+		Gtk::Action::create(
+			"HelpContents", Gtk::Stock::HELP, _("_Contents"),
+			_("Opens the Gobby manual"))),
 	action_help_about(
 		Gtk::Action::create(
 			"HelpAbout", Gtk::Stock::ABOUT, _("_About..."),
-			_("Shows Gobby's copyright and credits"))),
-
-	m_ui_manager(Gtk::UIManager::create())
+			_("Shows Gobby's copyright and credits")))
 {
 	// Add basic menu
 	m_ui_manager->add_ui_from_string(ui_desc);
@@ -310,6 +342,12 @@ Gobby::Header::Header(Preferences& preferences,
 	group_file->add(action_file_save_all,
 	                Gtk::AccelKey("<control><shift>L",
 			              "<Actions>/MenuFile/FileSaveAll"));
+	group_file->add(action_file_export_html,
+	                Gtk::AccelKey("<control><shift>H",
+			              "<Actions>/MenuFile/FileExportHtml"));
+	group_file->add(action_file_connect,
+	                Gtk::AccelKey("<control>T",
+	                              "<Actions>/MenuFile/FileConnect"));
 	group_file->add(action_file_close);
 	group_file->add(action_file_quit);
 
@@ -339,23 +377,36 @@ Gobby::Header::Header(Preferences& preferences,
 	group_edit->add(action_edit_preferences);
 
 	group_view->add(action_view);
+	group_view->add(
+		action_view_hide_user_colors,
+		Gtk::AccelKey("<shift><control>C",
+		              "<Actions>/MenuView/ViewHideUserColors"));
 	group_view->add(action_view_toolbar);
 	group_view->add(action_view_statusbar);
-	group_view->add(action_view_browser,
-	                Gtk::AccelKey("F9",
-			              "<Actions>/MenuView/ViewBrowser"));
-	group_view->add(action_view_userlist,
-	                Gtk::AccelKey("<control>F9",
-			              "<Actions>/MenuView/ViewUserList"));
+	group_view->add(action_view_browser, Gtk::AccelKey(
+		"F9", "<Actions>/MenuView/ViewBrowser"));
+	group_view->add(action_view_chat, Gtk::AccelKey(
+		"<shift>F9", "<Actions>/MenuView/ViewChat"));
+	group_view->add(action_view_document_userlist, Gtk::AccelKey(
+		"<control>F9", "<Actions>/MenuView/ViewDocumentUserList"));
+	group_view->add(action_view_chat_userlist, Gtk::AccelKey(
+		"<control><shift>F9", "<Actions>/MenuView/ViewChatUserList"));
 	group_view->add(action_view_highlight_mode);
 	group_view->add(action_view_highlight_none);
+
+	unsigned int language_menu_counter = 0;
 	for(LanguageMap::const_iterator iter =
 		action_view_highlight_languages.begin();
 	    iter != action_view_highlight_languages.end();
 	    ++ iter)
 	{
+		// We cannot use iter->first for the action name, since this
+		// is a localized string.
 		Glib::ustring section_action_name =
-			"ViewHighlightModeSection_" + iter->first;
+ 			Glib::ustring::compose("ViewHighlightModeSection_%1",
+				language_menu_counter);
+		++language_menu_counter;
+
 		Glib::ustring section_action_xml =
 			Glib::Markup::escape_text(section_action_name);
 
@@ -373,7 +424,7 @@ Gobby::Header::Header(Preferences& preferences,
 			Glib::ustring language_action_xml =
 				Glib::Markup::escape_text(
 					(*iter2)->get_name());
-			
+
 			Glib::ustring xml_desc =
 				"<ui>"
 				"  <menubar name=\"MenuMainBar\">"
@@ -395,6 +446,10 @@ Gobby::Header::Header(Preferences& preferences,
 	}
 
 	group_help->add(action_help);
+	group_help->add(action_help_contents,
+	                Gtk::AccelKey("F1",
+			              "<Actions>/MenuHelp/HelpContents"));
+
 	group_help->add(action_help_about);
 
 	m_ui_manager->insert_action_group(group_file);
@@ -425,11 +480,11 @@ Gobby::Header::Header(Preferences& preferences,
 
 #ifdef PLATFORM_OSX_NATIVE
 	ige_mac_menu_set_menu_bar(GTK_MENU_SHELL(m_menubar->gobj()));
-	
+
 	ige_mac_menu_set_quit_menu_item(GTK_MENU_ITEM(
 		m_ui_manager->get_widget(
 			"/MenuMainBar/MenuFile/FileQuit")->gobj()));
-	
+
 	ige_mac_menu_add_app_menu_item(
 		ige_mac_menu_add_app_menu_group(), GTK_MENU_ITEM(
 			m_ui_manager->get_widget(
